@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: IunoSettings.py 11266 2018-11-23 05:43:43Z Kevin $
+# $Id: IunoSettings.py 11300 2018-12-06 09:49:45Z Kevin $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Kevin $ (last)
-# $Date: 2018-11-23 14:43:43 +0900 (週五, 23 十一月 2018) $
-# $Revision: 11266 $
+# $Date: 2018-12-06 17:49:45 +0800 (Thu, 06 Dec 2018) $
+# $Revision: 11300 $
 """
 Default settings for this project if it can't import settings.
 """
@@ -82,4 +82,9 @@ INSTALLED_APPS = (
     'Iuppiter.test',
     'Iuno.tests',
     'Iuno.scaffold',
+    'Iuno.cloud.storage',
 )
+
+from Iuno.cloud.storage import DEFAULTS
+IUNO_CLOUD_STORAGE_GOOGLE_CREDENTIAL = DEFAULTS[
+    'IUNO_CLOUD_STORAGE_GOOGLE_CREDENTIAL']
