@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11289 2018-12-01 18:42:04Z Lavender $
+# $Id: __init__.py 11322 2018-12-25 06:32:28Z Kevin $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2018-12-02 03:42:04 +0900 (週日, 02 十二月 2018) $
-# $Revision: 11289 $
+# $Author: Kevin $ (last)
+# $Date: 2018-12-25 14:32:28 +0800 (??, 25 ??? 2018) $
+# $Revision: 11322 $
 
 from __future__ import print_function
 
@@ -32,6 +32,12 @@ DEVELOPMENT = 1
 STAGE = 2
 PRODUCTION = 3
 
+SERVER_MODES = {
+    'DEVELOPMENT': DEVELOPMENT,
+    'STAGE': STAGE,
+    'PRODUCTION': PRODUCTION,
+}
+
 try:
     import django
 
@@ -217,12 +223,10 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
 
     #=========================================================================
     # Server Mode.
-    serverModeDefaults = {
-        'DEVELOPMENT': DEVELOPMENT,
-        'STAGE': STAGE,
-        'PRODUCTION': PRODUCTION,
+    serverModeDefaults = SERVER_MODES
+    serverModeDefaults.update({
         'SERVER_MODE': DEVELOPMENT,
-    }
+    })
 
     # warnWithout('SERVER_MODE', settingsDict, serverModeDefaults)    
     reversedServerModes = {v: k for k, v in list(serverModeDefaults.items()) 
@@ -896,12 +900,11 @@ def detectServerMode(settingsDict):
     
     @param settingsDict Settings dict.
     """
-    _SERVER_MODE = (DEVELOPMENT 
-        if 'SERVER_MODE' not in os.environ 
-        else settingsDict[(os.environ['SERVER_MODE'])]
-    )
+    mode = os.environ.get('SERVER_MODE', 'DEVELOPMENT')
+    if mode in settingsDict:
+        return settingsDict[mode]
+    return SERVER_MODES[mode]
 
-    return _SERVER_MODE
 
 def detectDebug(settingsDict):
     """
