@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: __init__.py 11286 2018-11-30 08:48:45Z Kevin $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2018-07-16 18:31:00 +0900 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Author: Kevin $ (last)
+# $Date: 2018-11-30 16:48:45 +0800 (Fri, 30 Nov 2018) $
+# $Revision: 11286 $
 
 # Avoid conflict with Iuno.cloud.logging moudle.
 from __future__ import absolute_import
@@ -114,7 +114,7 @@ class LocalCacheProvider(singletonmixin.Singleton):
 localCache = LocalCacheProvider.getInstance()
 
 def attachSettings(settingsLocals, services=(
-                    'queue', 'mail', 'logging', 'browser'),
+                    'queue', 'mail', 'logging', 'browser', 'storage'),
                    serviceSettings=None,
                    loggingFile=None, loggingLevel=None,
                    cache=False, cacheDir=None):
