@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11257 2018-11-10 03:42:27Z Kevin $
+# $Id: __init__.py 11299 2018-12-06 09:24:18Z Kevin $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,14 +12,14 @@
 # limitations under the License.
 #
 # $Author: Kevin $ (last)
-# $Date: 2018-11-10 12:42:27 +0900 (週六, 10 十一月 2018) $
-# $Revision: 11257 $
+# $Date: 2018-12-06 17:24:18 +0800 (Thu, 06 Dec 2018) $
+# $Revision: 11299 $
 
 from googleapiclient.errors import HttpError
 
 from Iuno.cloud.storage.gos import path
 from Iuno.cloud.storage.gos.Service import (
-    service, BY_ID, BY_PATH, getFile, getFiles, handleHttpError)
+    ServiceSingleton, BY_ID, BY_PATH, getFile, getFiles, handleHttpError)
 
 
 def listdir(path):
@@ -36,6 +36,7 @@ def mkdir(path):
     parent = getFile("/".join(names[:-1]), type=BY_PATH).get("id")
     dirName = names[-1]
 
+    service = ServiceSingleton.getSingleton().service
     service.files().create(body={
         "name": dirName,
         "parents": [parent],
@@ -58,6 +59,8 @@ def makedirs(path):
 
 
 def _move(fileId, folderId):
+    service = ServiceSingleton.getSingleton().service
+
     # Retrieve the existing parents to remove
     try:
         file = service.files().get(
@@ -75,6 +78,8 @@ def _move(fileId, folderId):
 
 
 def _rename(fileId, title):
+    service = ServiceSingleton.getSingleton().service
+
     # Rename the file.
     service.files().update(
         fileId=fileId,
@@ -106,6 +111,7 @@ def remove(path):
 
     # delete the file
     try:
+        service = ServiceSingleton.getSingleton().service
         service.files().delete(fileId=fileId).execute()
     except HttpError as e:
         handleHttpError(e)
