@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: admin.py 11314 2018-12-14 05:31:25Z Kevin $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2018-07-16 17:31:00 +0800 (Mon, 16 Jul 2018) $
-# $Revision: 11172 $
+# $Author: Kevin $
+# $Date: 2018-12-14 13:31:25 +0800 (??, 14 ??? 2018) $
+# $Revision: 11314 $
 
 import os
 import datetime
@@ -38,7 +38,7 @@ from django.core.urlresolvers import reverse
 
 # ------------------------------------------------------------------------------
 from Iuno.template_editor.models import Static, Template, Version, FOLDER, FILE
-from Iuno.template_editor import BACKUP_FILE_DIR
+from Iuno.template_editor import BACKUP_FILE_DIR, toBytes
 
 TEXT_SUB_FILE_NAME = [
     'txt', 'css', 'js', 'html', 'htm',
@@ -79,7 +79,7 @@ def createVersion(model, node, conflict=False):
     with open(fullPath, 'rb') as f:
         data = f.read()
 
-    dirName = hashlib.md5(path).hexdigest()
+    dirName = hashlib.md5(toBytes(path)).hexdigest()
     checksum = hashlib.md5(data).hexdigest()
 
     createFile = False
@@ -154,7 +154,7 @@ def checkVersion(model):
         version = createVersion(model, node, conflict=True)
 
         path = node.path
-        dirName = hashlib.md5(path).hexdigest()
+        dirName = hashlib.md5(toBytes(path)).hexdigest()
 
         for version in Version.objects.filter(
             dirName=dirName, conflict=True):
