@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_tree.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: build_tree.py 11314 2018-12-14 05:31:25Z Kevin $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2018-07-16 18:31:00 +0900 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Author: Kevin $
+# $Date: 2018-12-14 13:31:25 +0800 (??, 14 ??? 2018) $
+# $Revision: 11314 $
 
 import os
 
@@ -27,7 +27,7 @@ from Iuno.template_editor import TEMPLATE_DIR, STATIC_DIR, BACKUP_FILE_DIR
 class Command(BaseCommand):
 
     def handle(self, *args, **options):
-        print "Delete all nodes..."
+        print("Delete all nodes...")
         Static.objects.all().delete()
         Template.objects.all().delete()
 
@@ -72,7 +72,7 @@ class Command(BaseCommand):
 
             if os.path.isfile(filePath):
                 if create:
-                    print "Create file node: %s" % filePath
+                    print("Create file node: %s" % filePath)
                     node = model.objects.create(
                         type=FILE,
                         name=f,
@@ -80,7 +80,7 @@ class Command(BaseCommand):
                     )
             else:
                 if create:
-                    print "Create folder node: %s" % filePath
+                    print("Create folder node: %s" % filePath)
                     node = model.objects.create(
                         type=FOLDER,
                         name=f,
